@@ -21,8 +21,8 @@ class EnvRecipe(RecipeStandard):
 
     def update(self, feature_name, config):
         super(EnvRecipe, self).update(feature_name, config)
-        [self.directory.add_to_rc('export %s=%s' % (c.upper(), config[c])) \
-             for c in config if c != 'recipe']
+        [self.directory.add_to_rc('export %s=%s' % (c.upper(), config['target'][c])) \
+             for c in config['target'] if c != 'recipe']
 
     def destroy(self, feature_name, config):
         super(EnvRecipe, self).destroy(feature_name, config)
